@@ -1,6 +1,7 @@
 import numpy as np
 
 from .interface import Interface
+from .base import _Jitter, component
 
 EPS = np.finfo(1.0).eps
 
@@ -78,7 +79,7 @@ def select_initial_step(interface: Interface, t0, y0, direction, order, rtol, at
     return min(100 * h0, h1)
 
 
-class Jacobian:  # pragma: no cover
+class Jacobian(_Jitter):  # pragma: no cover
     """
     Jacobian base class
     """
@@ -93,6 +94,7 @@ class Jacobian:  # pragma: no cover
         pass
 
 
+@component
 class UserDefinedJacobian(Jacobian):
     """
     Jacobian user defined class using ModelInterface get_jacobian(t)
@@ -104,6 +106,7 @@ class UserDefinedJacobian(Jacobian):
         return self.interface.get_jacobian(t)
 
 
+@component
 class NumericalJacobian(Jacobian):
     """
     Numerical Jacobian class using functions to calculate the jacobian automatically.
