@@ -18,7 +18,7 @@ from .solve_states import SolveEvent, SolveStatus
 solver_methods = {'RK45': RK45, 'Euler': Euler, 'BDF': BDF, 'NoDiff': NoDiff}
 
 SolverInfo = namedtuple('Info', ['status', 'event_id', 'step_info', 'initial_step', 'dt', 't', 'y', 'order_', 'roller',
-                            'solve_state', 'ix_eval', 'g', 'step_converged', 'event_trigger'])
+                            'solve_state', 'ix_eval', 'g', 'step_converged', 'event_trigger', 'direction'])
 
 try:
     FEPS = np.finfo(1.0).eps
@@ -198,6 +198,7 @@ class NumerousSolver:
             t_next_eval = t_eval[ix_eval]
 
             event_ix = -1
+            direction = 0
             t_event = t
             y_event = y
             t_event_previous = -1
@@ -269,9 +270,10 @@ class NumerousSolver:
                         te_array[2] = max(te_array)
 
 
-                    t_event, y_event, g, event_trigger = interface.get_state_events(g, state_events, roller, order,
-                                                                                     event_tolerance, imax,
-                                                                                     t_previous, y_previous, t, y)
+                    t_event, y_event, g, event_trigger, direction = interface.get_state_events(g, state_events, roller,
+                                                                                               order, event_tolerance,
+                                                                                               imax, t_previous,
+                                                                                               y_previous, t, y)
 
                 if not event_trigger and step_converged:
                     y_previous = y
@@ -280,7 +282,7 @@ class NumerousSolver:
                     if has_time_events and abs(t - t_next_time_event) < event_tolerance:
                         interface.set_states(y)
                         
-                        external, y_previous = interface.run_events(t, y, time_events)
+                        external, y_previous = interface.run_events(0, t, y, time_events)
 
                         interface.set_states(y_previous)
                         if external:
@@ -306,10 +308,11 @@ class NumerousSolver:
                         g = interface.get_state_event_results(t, y_previous, state_events)
                         interface.unset_events(state_events)
                     else:
+                        t_event_previous = t_event
                         failed_events = 0
                         warned_event = False
                         interface.set_states(y_event)
-                        external, y_previous = interface.run_events(t_event, y_event, state_events)
+                        external, y_previous = interface.run_events(direction, t_event, y_event, state_events)
                         interface.set_states(y_previous)
                         step_converged = False
 
@@ -355,7 +358,7 @@ class NumerousSolver:
             return SolverInfo(status=solve_status, event_id=solve_event_id, step_info=step_info,
                         dt=dt, t=t, y=np.ascontiguousarray(y), order_=order_, roller=roller, solve_state=_solve_state,
                         ix_eval=ix_eval, g=g, initial_step=initial_step, step_converged=step_converged,
-                        event_trigger=event_trigger)
+                        event_trigger=event_trigger, direction=direction)
 
         return _solve
 
@@ -550,7 +553,7 @@ class NumerousSolver:
                            atol * 1000)
 
         while info.status == SolveStatus.Running:
-            self._trigger_external_events(info.t, self.interface.get_states())
+            self._trigger_external_events(info.direction, info.t, self.interface.get_states())
             self.event_handler.handle_solve_event(self.interface, info.event_id, info.t)
 
             info = self._solve(self.interface,
@@ -579,13 +582,13 @@ class NumerousSolver:
         return info
 
 
-    def _trigger_external_events(self, t: float, y: np.array):
+    def _trigger_external_events(self, direction: int, t: float, y: np.array):
         external_events = [event for event in self.events.values() if event.is_external()]
         for event in external_events:
             if event.is_triggered():
                 external_event = self.external_events[event.id]
                 y = external_event.run_event_action(self.interface, t, y)
-                external_event.post_event(self.interface, t, y)
+                external_event.post_event(self.interface, direction, t, y)
                 event.clear()
                 self.interface.set_states(y)
 
